@@ -21,7 +21,7 @@ from collections import namedtuple
 from tornado import gen
 from nbformat.v4 import new_notebook
 from .cortx_authenticator import CortxAuthenticator
-from .utils import MultiPartUploadHelper
+from .utils import (MultiPartUploadHelper,get_key,get_path)
 import json 
 
 import nbformat
@@ -154,11 +154,11 @@ class CortxJupyter(ContentsManager):
         )
 
 
-def _key(config, path):
-    return config.prefix + path.lstrip('/')
+# def get_key(config, path):
+#     return config.prefix + path.lstrip('/')
 
-def _path(config, key):
-    return '/' + key[len(config.prefix):]
+# def get_path(config, key):
+#     return '/' + key[len(config.prefix):]
 
 
 def _final_path_component(key_or_path):
@@ -212,7 +212,7 @@ def _file_exists(config, path):
 
     @gen.coroutine
     def key_exists():
-        key = _key(config, path)
+        key = get_key(config, path)
         try:
             response = yield _head_object(config, config.bucket_name, key)
             
@@ -257,7 +257,7 @@ def _get_file_text(config, path, content):
 @gen.coroutine
 def _get_any(config, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
-    key = _key(config, path)
+    key = get_key(config, path)
     response = yield _get_object(config, config.bucket_name, key)
     file_bytes = response['Body'].read()
     last_modified_str = response['LastModified']
@@ -282,7 +282,7 @@ def _get_any(config, path, content, type, mimetype, format, decode):
 
 @gen.coroutine
 def _get_directory(config, path, content):
-    key = _key(config, path)
+    key = get_key(config, path)
     key_prefix = key if (key == '' or key[-1] == '/') else (key + '/')
     keys, directories = \
         (yield _list_immediate_child_keys_and_directories(config, key_prefix)) if content else \
@@ -303,7 +303,7 @@ def _get_directory(config, path, content):
             {
                 'type': 'directory',
                 'name': _final_path_component(directory),
-                'path': _path(config, directory),
+                'path': get_path(config, directory),
             }
             for directory in directories
             if directory not in all_keys
@@ -311,7 +311,7 @@ def _get_directory(config, path, content):
             {
                 'type': _type_from_path_not_directory(key),
                 'name': _final_path_component(key),
-                'path': _path(config, key),
+                'path': get_path(config, key),
                 'last_modified': last_modified,
             }
             for (key, last_modified) in keys
@@ -382,7 +382,7 @@ def _save_chunk(config, chunk, content_bytes, path, type, mimetype):
 @gen.coroutine
 def _save_bytes(config, content_bytes, path, type, mimetype):
 
-    object_name = _key(config, path)
+    object_name = get_key(config, path)
     response = _put_object(config, config.bucket_name, content_bytes, object_name)
     last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
 
@@ -460,7 +460,7 @@ def _delete_checkpoint(config, checkpoint_id, path):
 
 @gen.coroutine
 def _list_checkpoints(config, path):
-    key_prefix = _key(config, path + '/' + CHECKPOINT_NAME + '/')
+    key_prefix = get_key(config, path + '/' + CHECKPOINT_NAME + '/')
     keys, _ = yield _list_immediate_child_keys_and_directories(config, key_prefix)
     return [
         {
@@ -480,8 +480,8 @@ def _rename(config, old_path, new_path):
         raise HTTPServerError(400, "Target already exists")
 
     type = yield _type_from_path(config, old_path)
-    old_key = _key(config, old_path)
-    new_key = _key(config, new_path)
+    old_key = get_key(config, old_path)
+    new_key = get_key(config, new_path)
 
     def replace_key_prefix(string):
         return new_key + string[len(old_key):]
@@ -520,7 +520,7 @@ def _delete(config, path):
         raise HTTPServerError(400, "Can't delete root")
 
     type = _type_from_path(config, path)
-    root_key = _key(config, path)
+    root_key = get_key(config, path)
 
     object_key = \
         [] if type == 'directory' else \
@@ -607,8 +607,8 @@ def _copy(config, from_path, to_path):
         to_name = yield _increment_filename(config, name, to_path, insert='-Copy')
         to_path = u'{0}/{1}'.format(to_path, to_name)
 
-    from_key = _key(config, from_path)
-    to_key = _key(config, to_path)
+    from_key = get_key(config, from_path)
+    to_key = get_key(config, to_path)
 
     yield _copy_key(config, from_key, to_key)
     return {
