@@ -30,3 +30,10 @@ class MultiPartUploadHelper:
         self._remove_old_keys(now)
         del self._store[key]
 
+
+def get_key(config, path):
+    return config.prefix + path.lstrip('/')
+
+
+def get_path(config, key):
+    return '/' + key[len(config.prefix):]
\ No newline at end of file
